@@ -47,12 +47,12 @@ Output => Option<String>
 );
 hookit!(
 Hook => Shutdown,
-Input => (GlobalVariables),
+Input => (),
 Output => Option<Command>
 );
 hookit!(
 Hook => Startup,
-Input => (GlobalVariables),
+Input => (),
 Output => Option<Command>
 );
 hookit!(
@@ -65,6 +65,16 @@ Hook => SetOutputPrompt,
 Input => (GlobalVariables),
 Output => String
 );
+hookit!(
+Hook => BeforeCompiling,
+Input => (GlobalVariables),
+Output => ()
+);
+hookit!(
+Hook => AfterCompiling,
+Input => (GlobalVariables),
+Output => ()
+);
 
 #[derive(Clone, Debug, Serialize, Deserialize)]
 pub enum Command {
